CVE-2022-39048 | Security Lab
Author: Your Name
Description: Cross-Site Scripting (XSS) vulnerability in ServiceNow UI page assessment_redirect
Date: 2023-04-10T00:00:00-07:00

# CVE-2022-39048

PUBLISHED

# Summary

Cross-Site Scripting (XSS) vulnerability in ServiceNow UI page assessment_redirect

# Description

A XSS vulnerability was identified in the ServiceNow UI page assessment_redirect. To exploit this vulnerability, an attacker would need to persuade an authenticated user to click a maliciously crafted URL. Successful exploitation potentially could be used to conduct various client-side attacks, including, but not limited to, phishing, redirection, theft of CSRF tokens, and use of an authenticated user’s browser or session to attack other systems.

# Severity

6.1 (CVSS:3.1/AV:N/AC:L/PR:N/UI:R/S:C/C:L/I:L/A:N)

# Affected Versions

This vulnerability is present in the following Affected Product(s) listed below.

Affected Product(s)
cpe:2.3:a:servicenow:servicenow:san_diego:patch_3:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_2_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_2:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_1_hotfix_1b:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_1_hotfix_1a:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_1_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_6:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_4:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_4a:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_3_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_3_hotfix_2:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_3_hotfix_3:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_3_hotfix_4:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_2:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_3:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_4:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:quebec:-:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:quebec:patch_10:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:utah:-:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_1_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_1_hotfix_1b:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_1_hotfix_2:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_1_hotfix_3:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_2_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_2_hotfix_2:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_3_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_4_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_4_hotfix_1a:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_4_hotfix_1b:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_5:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_5_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_5_hotfix_2:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_6:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_7:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_6_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_6_hotfix_2:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_7_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_7a:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_7b:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_8:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_8_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_8_hotfix_2:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_9:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_9a:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_9b:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_9_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_10:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_10_hotfix_1:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_10_hotfix_2:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:rome:patch_10_hotfix_2a:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_4b:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_7:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:san_diego:patch_8:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:tokyo:-:*:*:*:*:*:*
cpe:2.3:a:servicenow:servicenow:tokyo:patch1:*:*:*:*:*:*

# References

- https://support.servicenow.com/
- https://support.servicenow.com/kb?id=kb_article_view&sysparm_article=KB1221892

# Change History

Date | Note
--- | ---
2023-04-10 | Initial publication
2023-04-18 | Last updated

Enter your search term...